==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/CONVERSIONOPTIONSUBEXPRESSIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CONVERSIONOPTIONSUBEXPRESSIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CONVERSIONOPTIONSUBEXPRESSIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONVERSIONOPTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONVERSIONOPTIONSUBEXPORDER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONVERSIONOPTIONSUBEXPRESSIONID_Type", propOrder = {
    "conversionoptionid",
    "conversionoptionsubexporder"
})
public class CONVERSIONOPTIONSUBEXPRESSIONID_Type {

    @XmlElement(name = "CONVERSIONOPTIONID", required = true)
    protected CONVERSIONOPTIONID_Type conversionoptionid;
    @XmlElement(name = "CONVERSIONOPTIONSUBEXPORDER")
    @XmlSchemaType(name = "long")
    protected int conversionoptionsubexporder;

    /**
     * Gets the value of the conversionoptionid property.
     * 
     * @return
     *     possible object is
     *     {@link CONVERSIONOPTIONID_Type }
     *     
     */
    public CONVERSIONOPTIONID_Type getCONVERSIONOPTIONID() {
        return conversionoptionid;
    }

    /**
     * Sets the value of the conversionoptionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CONVERSIONOPTIONID_Type }
     *     
     */
    public void setCONVERSIONOPTIONID(CONVERSIONOPTIONID_Type value) {
        this.conversionoptionid = value;
    }

    /**
     * Gets the value of the conversionoptionsubexporder property.
     * 
     */
    public int getCONVERSIONOPTIONSUBEXPORDER() {
        return conversionoptionsubexporder;
    }

    /**
     * Sets the value of the conversionoptionsubexporder property.
     * 
     */
    public void setCONVERSIONOPTIONSUBEXPORDER(int value) {
        this.conversionoptionsubexporder = value;
    }

}

==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/CONVERSIONOPTIONSUBEXPRESSIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CONVERSIONOPTIONSUBEXPRESSIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CONVERSIONOPTIONSUBEXPRESSIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONVERSIONOPTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONVERSIONOPTIONSUBEXPORDER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONVERSIONOPTIONSUBEXPRESSIONID_Type", propOrder = {
    "conversionoptionid",
    "conversionoptionsubexporder"
})
public class CONVERSIONOPTIONSUBEXPRESSIONID_Type {

    @XmlElement(name = "CONVERSIONOPTIONID", required = true)
    protected CONVERSIONOPTIONID_Type conversionoptionid;
    @XmlElement(name = "CONVERSIONOPTIONSUBEXPORDER")
    @XmlSchemaType(name = "long")
    protected int conversionoptionsubexporder;

    /**
     * Obtient la valeur de la propriété conversionoptionid.
     * 
     * @return
     *     possible object is
     *     {@link CONVERSIONOPTIONID_Type }
     *     
     */
    public CONVERSIONOPTIONID_Type getCONVERSIONOPTIONID() {
        return conversionoptionid;
    }

    /**
     * Définit la valeur de la propriété conversionoptionid.
     * 
     * @param value
     *     allowed object is
     *     {@link CONVERSIONOPTIONID_Type }
     *     
     */
    public void setCONVERSIONOPTIONID(CONVERSIONOPTIONID_Type value) {
        this.conversionoptionid = value;
    }

    /**
     * Obtient la valeur de la propriété conversionoptionsubexporder.
     * 
     */
    public int getCONVERSIONOPTIONSUBEXPORDER() {
        return conversionoptionsubexporder;
    }

    /**
     * Définit la valeur de la propriété conversionoptionsubexporder.
     * 
     */
    public void setCONVERSIONOPTIONSUBEXPORDER(int value) {
        this.conversionoptionsubexporder = value;
    }

}
